sqlobject.tests.test_SingleJoin module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_SingleJoin module

class `sqlobject.tests.test_SingleJoin.` `PersonWithAlbum`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `albumInstance`
  property `albumNone`
  `j` = person_with_album
  property `name`
  `q` = person_with_album
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.SingleJoin object>, <sqlobject.joins.SingleJoin object>]
    `joins` = [<sqlobject.joins.SOSingleJoin object>, <sqlobject.joins.SOSingleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_SingleJoin.PersonWithAlbum`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_with_album'

class `sqlobject.tests.test_SingleJoin.` `PhotoAlbum`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `color`
  `j` = photo_album
  property `person`
  property `personID`
  `q` = photo_album
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_SingleJoin.PhotoAlbum`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'photo_album'

`sqlobject.tests.test_SingleJoin.` `test_1`()